Suche nach installierten Paketen, die vom Ubuntu-Team nicht unterstützt werden


9

Wie kann ich überprüfen, ob ich Universe- oder Multiverse-Pakete installiert habe, die laut /etc/apt/sources.list"vom Ubuntu-Team VOLLSTÄNDIG UNTERSTÜTZT" sind?
Was ich suche, ist eine Befehlszeile für den Ubuntu 18 LTS-Server (keine GUI), um installierte Pakete nach Komponenten aufzulisten, einschließlich installierter Pakete, die nicht verfügbar sind apt-get(nicht Teil der in konfigurierten Archive /etc/apt/sources.list).
aptitude versions '?name(.)'listet die verfügbaren Pakete und ihren Installationsstatus auf, gibt jedoch weder ihre Quellkomponente aus, noch apt-cache.

Antworten:


14

Sie können den ubuntu-support-statusBefehl verwenden

$ ubuntu-support-status --help
Usage: ubuntu-support-status [options]

Options:
  -h, --help          show this help message and exit
  --show-unsupported  Show unsupported packages on this machine
  --show-supported    Show supported packages on this machine
  --show-all          Show all packages with their status
  --list              Show all packages in a list

mit entsprechendem Argument --show-unsupported.

Unten ist ein Beispiel aus meinem 16.04.5 LTS-System:

$ ubuntu-support-status --show-unsupported

Support status summary of 'hostname':

You have 94 packages (1.9%) supported until April 2021 (Community - 5y)
You have 2668 packages (54.0%) supported until April 2021 (Canonical - 5y)
You have 647 packages (13.1%) supported until April 2019 (Community - 3y)

You have 79 packages (1.6%) that can not/no-longer be downloaded
You have 1456 packages (29.4%) that are unsupported

No longer downloadable:
acroread acroread-bin:i386 cpp-4.4 cpp-4.5 cpp-4.6 
... 

Unsupported: 
abiword-plugin-grammar adequate aglfn alien android android-tools-adb 
android-tools-fastboot ant ant-optional antiword apt-file
...
y-ppa-manager yad zenmap

(Ich habe die hinzugefügt ..., um die Anzahl der Zeilen zu begrenzen).


Wenn Sie möchten, können Sie auch erwähnen vrms, "nicht freie" Software aufzulisten.
— DK Bose

In meiner Antwort unten erfahren Sie, was ich getan habe, um eine lesbare Liste von allem zu erhalten, was nicht vollständig unterstützt wird und ohne Unordnung.
— Jürgen

4
sudo apt install synaptic

Öffnen Sie den Synaptic Package Manager. Gehen Sie zu "Ursprung" (unten links).


Dies ist kein Befehlszeilenprogramm. Die GUI ist auf meinem Server nicht verfügbar.
— Jürgen

0

Das Debian-Wiki zeigt, wie Sie den Unterschied zwischen nativen und nicht nativen Paketen erkennen können.

Wenn Sie die Beziehung zwischen sources.listund installierten Paketen sehen möchten , können Sie dpkg --get-selectionsund apt-cache showund verwenden apt-get update.

Oder suchen Sie in einer Datenbank mit Paketen mit Curl.

In Fedora / RHEL gibt es ein Tool zum Überprüfen, ob Dateien aus unterstützten Paketen stammen.


dpkg --get-selectionsgibt keine Abschnitte aus. apt-cache show \*tut aber ist viel langsamer als akzeptierte Lösung, weil es viel mehr Informationen gibt.
— Jürgen

0

Was ich schließlich getan habe, um eine lesbare Liste von allem zu erhalten, was nicht vollständig unterstützt wird und ohne Unordnung:

# sed removes summary lines and packages supported for five years
# and prints one line per not fully supported package:
ubuntu-support-status --show-all | sed '0,/summary/ d; /^Support.*5y/,/^$/ d; /^You have/,/^$/ d; /:/ n; s- $--; s- -\n-g'

No longer downloadable:


Unsupported:
cgroup-tools
...

Supported until April 2021 (Community - 3y):
fonts-dejavu
libx86-1
openjdk-8-jre
openjdk-8-jre-headless
Durch die Nutzung unserer Website bestätigen Sie, dass Sie unsere Cookie-Richtlinie und Datenschutzrichtlinie gelesen und verstanden haben.
Licensed under cc by-sa 3.0 with attribution required.